==> org.opennms.features.activemq.shell-26.0.0-20200122.091534-53-sources.jar: org/opennms/features/activemq/shell/PurgeQueue.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2019 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2019 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.activemq.shell;

import org.apache.karaf.shell.api.action.Action;
import org.apache.karaf.shell.api.action.Argument;
import org.apache.karaf.shell.api.action.Command;
import org.apache.karaf.shell.api.action.Completion;
import org.apache.karaf.shell.api.action.lifecycle.Reference;
import org.apache.karaf.shell.api.action.lifecycle.Service;
import org.opennms.features.activemq.broker.api.ManagedBroker;
import org.opennms.features.activemq.broker.api.ManagedDestination;

@Command(scope = "opennms-activemq", name = "purge-queue", description = "Purge the content of an ActiveMQ queue.")
@Service
public class PurgeQueue implements Action {

    @Reference(optional = true)
    private ManagedBroker broker;

    @Argument(name = "queue name", required = true)
    @Completion(QueueNameCompleter.class)
    private String queueName;

    @Override
    public Object execute() throws Exception {
        if (broker == null) {
            System.out.println("(No broker available.)");
            return null;
        }

        final ManagedDestination queue = broker.getDestinations().stream()
                .filter(ManagedDestination::isQueue)
                .filter(q -> queueName.trim().equalsIgnoreCase(q.getName()))
                .findFirst()
                .orElse(null);

        if (queue == null) {
            System.out.printf("No queue named '%s' found.\n", queueName);
        } else {
            System.out.println("Purging: " + queue.getName());
            queue.purge();
        }
        return null;
    }
}

==> org.opennms.features.activemq.shell-27.1.0-sources.jar: org/opennms/features/activemq/shell/PurgeQueue.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2019 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2019 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.activemq.shell;

import org.apache.karaf.shell.api.action.Action;
import org.apache.karaf.shell.api.action.Argument;
import org.apache.karaf.shell.api.action.Command;
import org.apache.karaf.shell.api.action.Completion;
import org.apache.karaf.shell.api.action.lifecycle.Reference;
import org.apache.karaf.shell.api.action.lifecycle.Service;
import org.opennms.features.activemq.broker.api.ManagedBroker;
import org.opennms.features.activemq.broker.api.ManagedDestination;

@Command(scope = "opennms", name = "activemq-purge-queue", description = "Purge the content of an ActiveMQ queue.")
@Service
public class PurgeQueue implements Action {

    @Reference(optional = true)
    private ManagedBroker broker;

    @Argument(name = "queue name", required = true)
    @Completion(QueueNameCompleter.class)
    private String queueName;

    @Override
    public Object execute() throws Exception {
        if (broker == null) {
            System.out.println("(No broker available.)");
            return null;
        }

        final ManagedDestination queue = broker.getDestinations().stream()
                .filter(ManagedDestination::isQueue)
                .filter(q -> queueName.trim().equalsIgnoreCase(q.getName()))
                .findFirst()
                .orElse(null);

        if (queue == null) {
            System.out.printf("No queue named '%s' found.\n", queueName);
        } else {
            System.out.println("Purging: " + queue.getName());
            queue.purge();
        }
        return null;
    }
}
